@@ -100,12 +100,14 @@ void call_accept(Call *call)
 	eXosip_call_send_answer(call->tid,200,msg);
  	call->audio_stream=audio_stream_new(call->audio.localport,call->root->ipv6);
 	audio_stream_start_with_files(call->audio_stream, call->profile,
-				call->audio.remaddr,call->audio.remoteport,call->audio.pt,20,hellofile,record_file);
+				call->audio.remaddr,call->audio.remoteport,call->audio.remoteport+1,
+				 call->audio.pt,20,hellofile,record_file);
 	call_count++;
 #ifdef VIDEO_ENABLED
 	if (call->video.remoteport!=0){
 		video_stream_send_only_start(call->video_stream,call->profile,
-			call->video.remaddr,call->video.remoteport,call->video.pt, 60, "/dev/video0");
+			call->video.remaddr,call->video.remoteport,call->video.remoteport+1,call->video.pt, 60, 
+			ms_web_cam_manager_get_default_cam(ms_web_cam_manager_get()));
 	}
 #endif
 	call->time=time(NULL);
@@ -325,7 +327,7 @@ Call * call_new(Sipomatic *root, eXosip_event_t *ev)
 	sdp_context_t *sdpc;
 	
 	sdp=eXosip_get_sdp_info(ev->request);
-	sdpc=sdp_handler_create_context(&sipomatic_sdp_handler,NULL,"sipomatic");
+	sdpc=sdp_handler_create_context(&sipomatic_sdp_handler,NULL,"sipomatic",NULL);
 	obj=ms_new0(Call,1);
 	obj->profile=rtp_profile_new("remote");
 	eXosip_call_send_answer(ev->tid,100,NULL);
