@@ -175,6 +175,35 @@ LinphoneFriend *linphone_friend_new_with_addr(const char *addr){
 	return fr;
 }
 
+void linphone_core_interpret_friend_uri(LinphoneCore *lc, const char *uri, char **result){
+	int err;
+	osip_from_t *fr=NULL;
+	osip_from_init(&fr);
+	err=osip_from_parse(fr,uri);
+	if (err<0){
+		char *tmp=NULL;
+		if (strchr(uri,'@')!=NULL){
+			/*try adding sip:*/
+			tmp=ms_strdup_printf("sip:%s",uri);
+		}else if (lc->default_proxy!=NULL){
+			/*try adding domain part from default current proxy*/
+			osip_from_t *id=NULL;
+			osip_from_init(&id);
+			if (osip_from_parse(id,linphone_core_get_identity(lc))==0){
+				if (id->url->port!=NULL && strlen(id->url->port)>0)
+					tmp=ms_strdup_printf("sip:%s@%s:%s",uri,id->url->host,id->url->port);
+				else tmp=ms_strdup_printf("sip:%s@%s",uri,id->url->host);
+			}
+			osip_from_free(id);
+		}
+		if (osip_from_parse(fr,tmp)==0){
+			/*looks good */
+			ms_message("%s interpreted as %s",uri,tmp);
+			*result=tmp;
+		}else *result=NULL;
+	}else *result=ms_strdup(uri);
+	osip_from_free(fr);
+}
 
 int linphone_friend_set_sip_addr(LinphoneFriend *lf, const char *addr){
 	int err;
@@ -585,6 +614,8 @@ void linphone_friend_apply(LinphoneFriend *fr, LinphoneCore *lc){
 	}
 	fr->lc=lc;
 	
+	linphone_core_write_friends_config(lc);
+
 	if (fr->inc_subscribe_pending){
 		switch(fr->pol){
 			case LinphoneSPWait:
@@ -622,8 +653,8 @@ void linphone_core_add_friend(LinphoneCore *lc, LinphoneFriend *lf)
 {
 	ms_return_if_fail(lf->lc==NULL);
 	ms_return_if_fail(lf->url!=NULL);
-	linphone_friend_apply(lf,lc);
 	lc->friends=ms_list_append(lc->friends,lf);
+	linphone_friend_apply(lf,lc);
 	return ;
 }
 
@@ -632,6 +663,7 @@ void linphone_core_remove_friend(LinphoneCore *lc, LinphoneFriend* fl){
 	if (el!=NULL){
 		lc->friends=ms_list_remove_link(lc->friends,el);
 		linphone_friend_destroy((LinphoneFriend*)el->data);
+		linphone_core_write_friends_config(lc);
 	}
 }
 
@@ -734,3 +766,15 @@ void linphone_friend_write_to_config_file(LpConfig *config, LinphoneFriend *lf,
 		lp_config_set_int(config,key,"proxy",a);
 	}else lp_config_set_int(config,key,"proxy",-1);
 }
+
+void linphone_core_write_friends_config(LinphoneCore* lc)
+{
+	MSList *elem;
+	int i;
+	if (!lc->ready) return; /*dont write config when reading it !*/
+	for (elem=lc->friends,i=0; elem!=NULL; elem=ms_list_next(elem),i++){
+		linphone_friend_write_to_config_file(lc->config,(LinphoneFriend*)elem->data,i);
+	}
+	linphone_friend_write_to_config_file(lc->config,NULL,i);	/* set the end */
+}
+
