@@ -160,7 +160,7 @@ void check_sound_device(LinphoneCore *lc)
 #define IP4_HDR_SZ 20   /*20 is the minimum, but there may be some options*/
 
 const char *payload_type_get_description(PayloadType *pt){
-	return (const char *)pt->user_data;
+	return _((const char *)pt->user_data);
 }	
 
 void payload_type_set_enable(PayloadType *pt,int value) 
@@ -195,13 +195,14 @@ static double get_audio_payload_bandwidth(const PayloadType *pt){
 	return packet_size*8.0*npacket;
 }
 
-void linphone_core_update_allocated_audio_bandwidth(LinphoneCore *lc, const PayloadType *pt){
+void linphone_core_update_allocated_audio_bandwidth_in_call(LinphoneCore *lc, const PayloadType *pt){
 	lc->audio_bw=(int)(get_audio_payload_bandwidth(pt)/1000.0);
 	/*update*/
+	linphone_core_set_download_bandwidth(lc,lc->net_conf.download_bw);
 	linphone_core_set_upload_bandwidth(lc,lc->net_conf.upload_bw);
 }
 
-static void update_allocated_audio_bandwidth(LinphoneCore *lc){
+void linphone_core_update_allocated_audio_bandwidth(LinphoneCore *lc){
 	const MSList *elem;
 	PayloadType *max=NULL;
 	for(elem=linphone_core_get_audio_codecs(lc);elem!=NULL;elem=elem->next){
@@ -214,7 +215,7 @@ static void update_allocated_audio_bandwidth(LinphoneCore *lc){
 		}
 	}
 	if (max) {
-		linphone_core_update_allocated_audio_bandwidth(lc,max);
+		linphone_core_update_allocated_audio_bandwidth_in_call(lc,max);
 	}
 }
 
@@ -230,7 +231,7 @@ bool_t linphone_core_check_payload_type_usability(LinphoneCore *lc, PayloadType
 	  This must be done outside calls, because after sdp negociation
 	  the audio bandwidth is refined to the selected codec
 	*/
-	if (!linphone_core_in_call(lc)) update_allocated_audio_bandwidth(lc);
+	if (!linphone_core_in_call(lc)) linphone_core_update_allocated_audio_bandwidth(lc);
 	min_audio_bw=get_min_bandwidth(linphone_core_get_download_bandwidth(lc),
 					linphone_core_get_upload_bandwidth(lc));
 	if (min_audio_bw==0) min_audio_bw=-1;
@@ -249,7 +250,7 @@ bool_t linphone_core_check_payload_type_usability(LinphoneCore *lc, PayloadType
 				if (min_video_bw>0)
 					pt->normal_bitrate=min_video_bw*1000;
 				else 
-					pt->normal_bitrate=512000;
+					pt->normal_bitrate=1500000; /*around 1.5 Mbit/s*/
 				ret=TRUE;
 			}
 			else ret=FALSE;
@@ -389,6 +390,7 @@ void linphone_core_setup_local_rtp_profile(LinphoneCore *lc)
 	/* set the fixed lists instead:*/
 	lc->codecs_conf.audio_codecs=audiopt;
 	lc->codecs_conf.video_codecs=videopt;
+	linphone_core_update_allocated_audio_bandwidth(lc);
 }
 
 int from_2char_without_params(osip_from_t *from,char **str)
@@ -499,7 +501,7 @@ static ortp_socket_t create_socket(int local_port){
 	return sock;
 }
 
-static int sendStunRequest(int sock, const struct sockaddr *server, socklen_t addrlen, int id){
+static int sendStunRequest(int sock, const struct sockaddr *server, socklen_t addrlen, int id, bool_t changeAddr){
 	char buf[STUN_MAX_MESSAGE_SIZE];
 	int len = STUN_MAX_MESSAGE_SIZE;
 	StunAtrString username;
@@ -509,8 +511,8 @@ static int sendStunRequest(int sock, const struct sockaddr *server, socklen_t ad
 	memset(&req, 0, sizeof(StunMessage));
 	memset(&username,0,sizeof(username));
 	memset(&password,0,sizeof(password));
-	stunBuildReqSimple( &req, &username, FALSE , FALSE , id);
-	len = stunEncodeMessage( &req, buf, len, &password, FALSE);
+	stunBuildReqSimple( &req, &username, changeAddr , changeAddr , id);
+	len = stunEncodeMessage( &req, buf, len, &password);
 	if (len<=0){
 		ms_error("Fail to encode stun message.");
 		return -1;
@@ -552,14 +554,15 @@ static int parse_stun_server_addr(const char *server, struct sockaddr_storage *s
 	return 0;
 }
 
-static int recvStunResponse(ortp_socket_t sock, char *ipaddr, int *port){
+static int recvStunResponse(ortp_socket_t sock, char *ipaddr, int *port, int *id){
 	char buf[STUN_MAX_MESSAGE_SIZE];
    	int len = STUN_MAX_MESSAGE_SIZE;
 	StunMessage resp;
 	len=recv(sock,buf,len,0);
 	if (len>0){
 		struct in_addr ia;
-		stunParseMessage(buf,len, &resp,FALSE );
+		stunParseMessage(buf,len, &resp );
+		*id=resp.msgHdr.tr_id.octet[0];
 		*port = resp.mappedAddress.ipv4.port;
 		ia.s_addr=htonl(resp.mappedAddress.ipv4.addr);
 		strncpy(ipaddr,inet_ntoa(ia),LINPHONE_IPADDR_SIZE);
@@ -569,7 +572,7 @@ static int recvStunResponse(ortp_socket_t sock, char *ipaddr, int *port){
 
 void linphone_core_run_stun_tests(LinphoneCore *lc, LinphoneCall *call){
 	const char *server=linphone_core_get_stun_server(lc);
-	
+
 	if (lc->sip_conf.ipv6_enabled){
 		ms_warning("stun support is not implemented for ipv6");
 		return;
@@ -580,6 +583,7 @@ void linphone_core_run_stun_tests(LinphoneCore *lc, LinphoneCall *call){
 		ortp_socket_t sock1=-1, sock2=-1;
 		bool_t video_enabled=linphone_core_video_enabled(lc);
 		bool_t got_audio,got_video;
+		bool_t cone_audio=FALSE,cone_video=FALSE;
 		struct timeval init,cur;
 		if (parse_stun_server_addr(server,&ss,&ss_len)<0){
 			ms_error("Fail to parser stun server address: %s",server);
@@ -595,15 +599,18 @@ void linphone_core_run_stun_tests(LinphoneCore *lc, LinphoneCall *call){
 			sock2=create_socket(linphone_core_get_video_port(lc));
 			if (sock2<0) return ;
 		}
-		sendStunRequest(sock1,(struct sockaddr*)&ss,ss_len,1);
-		if (sock2>=0)
-			sendStunRequest(sock2,(struct sockaddr*)&ss,ss_len,2);
-		
+		sendStunRequest(sock1,(struct sockaddr*)&ss,ss_len,11,TRUE);
+		sendStunRequest(sock1,(struct sockaddr*)&ss,ss_len,1,FALSE);
+		if (sock2>=0){
+			sendStunRequest(sock2,(struct sockaddr*)&ss,ss_len,22,TRUE);
+			sendStunRequest(sock2,(struct sockaddr*)&ss,ss_len,2,FALSE);
+		}
 		got_audio=FALSE;
 		got_video=FALSE;
 		gettimeofday(&init,NULL);
 		do{
 			double elapsed;
+			int id;
 #ifdef WIN32
 			Sleep(10);
 #else
@@ -611,17 +618,21 @@ void linphone_core_run_stun_tests(LinphoneCore *lc, LinphoneCall *call){
 #endif
 
 			if (recvStunResponse(sock1,call->audio_params.natd_addr,
-						&call->audio_params.natd_port)>0){
+						&call->audio_params.natd_port,&id)>0){
 				ms_message("STUN test result: local audio port maps to %s:%i",
 						call->audio_params.natd_addr,
 						call->audio_params.natd_port);
+				if (id==11)
+					cone_audio=TRUE;
 				got_audio=TRUE;
 			}
 			if (recvStunResponse(sock2,call->video_params.natd_addr,
-							&call->video_params.natd_port)>0){
+							&call->video_params.natd_port,&id)>0){
 				ms_message("STUN test result: local video port maps to %s:%i",
 					call->video_params.natd_addr,
 					call->video_params.natd_port);
+				if (id==22)
+					cone_video=TRUE;
 				got_video=TRUE;
 			}
 			gettimeofday(&cur,NULL);
@@ -630,9 +641,21 @@ void linphone_core_run_stun_tests(LinphoneCore *lc, LinphoneCall *call){
 		}while(!(got_audio && (got_video||sock2<0)  ) );
 		if (!got_audio){
 			ms_error("No stun server response for audio port.");
+		}else{
+			if (!cone_audio) {
+				ms_warning("NAT is symmetric for audio port");
+				call->audio_params.natd_port=0;
+			}
 		}
-		if (!got_video && sock2>=0){
-			ms_error("No stun server response for video port.");
+		if (sock2>=0){
+			if (!got_video){
+				ms_error("No stun server response for video port.");
+			}else{
+				if (!cone_video) {
+					ms_warning("NAT is symmetric for video port.");
+					call->video_params.natd_port=0;
+				}
+			}
 		}
 		close_socket(sock1);
 		if (sock2>=0) close_socket(sock2);
