@@ -49,6 +49,10 @@ void sip_setup_register_all(void){
 	}
 }
 
+const MSList * linphone_core_get_sip_setups(LinphoneCore *lc){
+	return registered_sip_setups;
+}
+
 SipSetup *sip_setup_lookup(const char *type_name){
 	MSList *elem;
 	for(elem=registered_sip_setups;elem!=NULL;elem=elem->next){
@@ -73,7 +77,7 @@ void sip_setup_unregister_all(void){
 	for(elem=registered_sip_setups;elem!=NULL;elem=elem->next){
 		SipSetup *ss=(SipSetup*)elem->data;
 		if (ss->initialized){
-			ss->exit();
+			if (ss->exit) ss->exit();
 			ss->initialized=FALSE;
 		}
 	}
@@ -94,6 +98,10 @@ SipSetupContext *sip_setup_context_new(SipSetup *s, struct _LinphoneProxyConfig
 	return obj;
 }
 
+unsigned int sip_setup_get_capabilities(SipSetup *s){
+	return s->capabilities;
+}
+
 int sip_setup_context_get_capabilities(SipSetupContext *ctx){
 	return ctx->funcs->capabilities;
 }
@@ -104,6 +112,12 @@ int sip_setup_context_create_account(SipSetupContext * ctx, const char *uri, con
 	else return -1;
 }
 
+int sip_setup_context_account_exists(SipSetupContext *ctx, const char *uri){
+	if (ctx->funcs->account_exists)
+		return ctx->funcs->account_exists(ctx,uri);
+	return -1;
+}
+
 int sip_setup_context_login_account(SipSetupContext * ctx, const char *uri, const char *passwd){
 	osip_from_t *from;
 	osip_from_init(&from);
