@@ -120,6 +120,10 @@ void linphone_gtk_contact_activated(GtkTreeView     *treeview,
                                     GtkTreeViewColumn *column,
                                         gpointer         user_data)
 {
+	linphone_gtk_call_selected(treeview);
+}
+
+void linphone_gtk_contact_clicked(GtkTreeView     *treeview){
 	linphone_gtk_set_selection_to_uri_bar(treeview);
 }
 
@@ -195,6 +199,8 @@ static void linphone_gtk_friend_list_init(GtkWidget *friendlist)
 	gtk_tree_view_column_set_min_width (column, 29);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (friendlist), column);
 
+	gtk_tree_view_column_set_visible(column,linphone_gtk_get_ui_config_int("friendlist_icon",1));
+
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Name"),
                                                    renderer,
@@ -209,6 +215,7 @@ static void linphone_gtk_friend_list_init(GtkWidget *friendlist)
                                                    NULL);
 	g_object_set (G_OBJECT(column), "resizable", TRUE, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (friendlist), column);
+	gtk_tree_view_column_set_visible(column,linphone_gtk_get_ui_config_int("friendlist_status",1));
 	
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (friendlist));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
@@ -356,22 +363,27 @@ void linphone_gtk_contact_cancel(GtkWidget *button){
 void linphone_gtk_contact_ok(GtkWidget *button){
 	GtkWidget *w=gtk_widget_get_toplevel(button);
 	LinphoneFriend *lf=(LinphoneFriend*)g_object_get_data(G_OBJECT(w),"friend_ref");
-	gboolean editing=FALSE,show_presence,allow_presence;
+	char *fixed_uri=NULL;
+	gboolean show_presence,allow_presence;
 	const gchar *name,*uri;
 	if (lf==NULL){
 		lf=linphone_friend_new();
-	}else{
-		editing=TRUE;
 	}
 	name=gtk_entry_get_text(GTK_ENTRY(linphone_gtk_get_widget(w,"name")));
 	uri=gtk_entry_get_text(GTK_ENTRY(linphone_gtk_get_widget(w,"sip_address")));
 	show_presence=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(w,"show_presence")));
 	allow_presence=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(w,"allow_presence")));
-	linphone_friend_set_sip_addr(lf,uri);
+	linphone_core_interpret_friend_uri(linphone_gtk_get_core(),uri,&fixed_uri);
+	if (fixed_uri==NULL){
+		linphone_gtk_display_something(GTK_MESSAGE_WARNING,_("Invalid sip contact !"));
+		return ;
+	}
+	linphone_friend_set_sip_addr(lf,fixed_uri);
+	ms_free(fixed_uri);
 	linphone_friend_set_name(lf,name);
 	linphone_friend_send_subscribe(lf,show_presence);
 	linphone_friend_set_inc_subscribe_policy(lf,allow_presence==TRUE ? LinphoneSPAccept : LinphoneSPDeny);
-	if (editing){
+	if (linphone_friend_in_list(lf)) {
 		linphone_friend_done(lf);
 	}else{
 		linphone_core_add_friend(linphone_gtk_get_core(),lf);
@@ -385,19 +397,32 @@ static GtkWidget *linphone_gtk_create_contact_menu(GtkWidget *contact_list){
 	GtkWidget *menu_item;
 	gchar *call_label=NULL;
 	gchar *text_label=NULL;
+	gchar *edit_label=NULL;
+	gchar *delete_label=NULL;
 	gchar *name=NULL;
 	GtkTreeSelection *select;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	GtkWidget *image;
+	LinphoneCore *lc=linphone_gtk_get_core();
+	LinphoneProxyConfig *cfg=NULL;
+	SipSetupContext * ssc=NULL;
+
+	linphone_core_get_default_proxy(lc,&cfg);
+	if (cfg){
+		ssc=linphone_proxy_config_get_sip_setup_context(cfg);
+	}
+
 	g_signal_connect(G_OBJECT(menu), "selection-done", G_CALLBACK (gtk_widget_destroy), NULL);
 	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(contact_list));
 	if (gtk_tree_selection_get_selected (select, &model, &iter)){
 		gtk_tree_model_get(model, &iter,FRIEND_NAME , &name, -1);
 		call_label=g_strdup_printf(_("Call %s"),name);
 		text_label=g_strdup_printf(_("Send text to %s"),name);
+		edit_label=g_strdup_printf(_("Edit contact '%s'"),name);
+		delete_label=g_strdup_printf(_("Delete contact '%s'"),name);
 		g_free(name);
-	}else g_warning("No selection");
+	}
 	if (call_label){
 		menu_item=gtk_image_menu_item_new_with_label(call_label);
 		image=gtk_image_new_from_stock(GTK_STOCK_NETWORK,GTK_ICON_SIZE_MENU);
@@ -416,22 +441,50 @@ static GtkWidget *linphone_gtk_create_contact_menu(GtkWidget *contact_list){
 		gtk_menu_shell_append(GTK_MENU_SHELL(menu),menu_item);
 		g_signal_connect_swapped(G_OBJECT(menu_item),"activate",(GCallback)linphone_gtk_chat_selected,contact_list);
 	}
-	menu_item=gtk_image_menu_item_new_from_stock(GTK_STOCK_EDIT,NULL);
-	gtk_widget_show(menu_item);
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu),menu_item);
-	g_signal_connect_swapped(G_OBJECT(menu_item),"activate",(GCallback)linphone_gtk_edit_contact,contact_list);
-	menu_item=gtk_image_menu_item_new_from_stock(GTK_STOCK_DELETE,NULL);
-	gtk_widget_show(menu_item);
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu),menu_item);
-	g_signal_connect_swapped(G_OBJECT(menu_item),"activate",(GCallback)linphone_gtk_remove_contact,contact_list);
+	if (edit_label){
+		menu_item=gtk_image_menu_item_new_with_label(edit_label);
+		image=gtk_image_new_from_stock(GTK_STOCK_EDIT,GTK_ICON_SIZE_MENU);
+		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),image);
+		gtk_widget_show(image);
+		gtk_widget_show(menu_item);
+		gtk_menu_shell_append(GTK_MENU_SHELL(menu),menu_item);
+		g_signal_connect_swapped(G_OBJECT(menu_item),"activate",(GCallback)linphone_gtk_edit_contact,contact_list);
+	}
+	if (delete_label){
+		menu_item=gtk_image_menu_item_new_with_label(delete_label);
+		image=gtk_image_new_from_stock(GTK_STOCK_DELETE,GTK_ICON_SIZE_MENU);
+		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),image);
+		gtk_widget_show(image);
+		gtk_widget_show(menu_item);
+		gtk_menu_shell_append(GTK_MENU_SHELL(menu),menu_item);
+		g_signal_connect_swapped(G_OBJECT(menu_item),"activate",(GCallback)linphone_gtk_remove_contact,contact_list);
+	}
+	
+
+	if (ssc && (sip_setup_context_get_capabilities(ssc) & SIP_SETUP_CAP_BUDDY_LOOKUP)) {
+		gchar *tmp=g_strdup_printf(_("Add new contact from %s directory"),linphone_proxy_config_get_domain(cfg));
+		menu_item=gtk_image_menu_item_new_with_label(tmp);
+		g_free(tmp);
+		image=gtk_image_new_from_stock(GTK_STOCK_ADD,GTK_ICON_SIZE_MENU);
+		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),image);
+		gtk_widget_show(image);
+		gtk_widget_show(menu_item);
+		gtk_menu_shell_append(GTK_MENU_SHELL(menu),menu_item);
+		g_signal_connect_swapped(G_OBJECT(menu_item),"activate",(GCallback)linphone_gtk_show_buddy_lookup_window,ssc);
+		gtk_widget_show(menu);
+	}
+	
 	menu_item=gtk_image_menu_item_new_from_stock(GTK_STOCK_ADD,NULL);
 	gtk_widget_show(menu_item);
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu),menu_item);
 	g_signal_connect_swapped(G_OBJECT(menu_item),"activate",(GCallback)linphone_gtk_add_contact,contact_list);
 	gtk_widget_show(menu);
 	gtk_menu_attach_to_widget (GTK_MENU (menu), contact_list, NULL);
+
 	if (call_label) g_free(call_label);
 	if (text_label) g_free(text_label);
+	if (edit_label) g_free(edit_label);
+	if (delete_label) g_free(delete_label);
 	return menu;
 }
 
