@@ -74,8 +74,7 @@ static LinphoneCoreVTable vtable={
 	.display_question=linphone_gtk_display_question,
 	.call_log_updated=linphone_gtk_call_log_updated,
 	.text_received=linphone_gtk_text_received,
-	.general_state=linphone_gtk_general_state,
-	.waiting=linphone_gtk_wait
+	.general_state=linphone_gtk_general_state
 };
 
 static gboolean verbose=0;
@@ -120,6 +119,7 @@ const char *linphone_gtk_get_config_file(){
 static void linphone_gtk_init_liblinphone(const char *file){
 	linphone_core_set_user_agent("Linphone", LINPHONE_VERSION);
 	the_core=linphone_core_new(&vtable,file,NULL);
+	linphone_core_set_waiting_callback(the_core,linphone_gtk_wait);
 }
 
 
@@ -740,6 +740,7 @@ static void linphone_gtk_init_status_icon(){
 	g_signal_connect(G_OBJECT(icon),"popup-menu",(GCallback)icon_popup_menu,NULL);
 	title=linphone_gtk_get_ui_config("title",_("Linphone - a video internet phone"));
 	gtk_status_icon_set_tooltip(icon,title);
+	gtk_status_icon_set_visible(icon,TRUE);
 	g_object_set_data(G_OBJECT(icon),"menu",menu);
 	g_object_weak_ref(G_OBJECT(icon),(GWeakNotify)gtk_widget_destroy,menu);
 }
@@ -793,6 +794,18 @@ static void linphone_gtk_check_menu_items(void){
 					audio_only ? "audio_only_item" : "video_item")), TRUE);
 }
 
+static gboolean linphone_gtk_can_manage_accounts(){
+	LinphoneCore *lc=linphone_gtk_get_core();
+	const MSList *elem;
+	for(elem=linphone_core_get_sip_setups(lc);elem!=NULL;elem=elem->next){
+		SipSetup *ss=(SipSetup*)elem->data;
+		if (sip_setup_get_capabilities(ss) & SIP_SETUP_CAP_ACCOUNT_MANAGER){
+			return TRUE;
+		}
+	}
+	return FALSE;
+}
+
 static void linphone_gtk_configure_main_window(){
 	static gboolean config_loaded=FALSE;
 	static const char *title;
@@ -808,7 +821,12 @@ static void linphone_gtk_configure_main_window(){
 		config_loaded=TRUE;
 	}
 	linphone_gtk_configure_window(w,"main_window");
-	if (title) gtk_window_set_title(GTK_WINDOW(w),title);
+	if (title) {
+		gtk_window_set_title(GTK_WINDOW(w),title);
+#if GTK_CHECK_VERSION(2,16,0)
+		gtk_menu_item_set_label(GTK_MENU_ITEM(linphone_gtk_get_widget(w,"main_menu")),title);
+#endif
+	}
 	if (start_call_icon){
 		GdkPixbuf *pbuf=create_pixbuf(start_call_icon);
 		gtk_image_set_from_pixbuf(GTK_IMAGE(linphone_gtk_get_widget(w,"start_call_icon")),pbuf);
@@ -825,6 +843,8 @@ static void linphone_gtk_configure_main_window(){
 		tmp=g_strdup(home);
 		g_object_set_data(G_OBJECT(menu_item),"home",tmp);
 	}
+	if (!linphone_gtk_can_manage_accounts())
+		gtk_widget_hide(linphone_gtk_get_widget(w,"run_assistant"));
 }
 
 static void linphone_gtk_init_main_window(){
