@@ -19,16 +19,44 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "linphone.h"
 
-static void linphone_gtk_fill_combo_box(GtkWidget *combo, const char **devices, const char *selected){
+typedef enum {
+	CAP_IGNORE,
+	CAP_PLAYBACK,
+	CAP_CAPTURE
+}DeviceCap;
+
+static void linphone_gtk_fill_combo_box(GtkWidget *combo, const char **devices, const char *selected, DeviceCap cap){
 	const char **p=devices;
 	int i=0,active=0;
 	/* glade creates a combo box without list model and text renderer,
 	unless we fill it with a dummy text.
 	This dummy text needs to be removed first*/
 	gtk_combo_box_remove_text(GTK_COMBO_BOX(combo),0);
-	for(;*p!=NULL;++p,++i){
-		gtk_combo_box_append_text(GTK_COMBO_BOX(combo),*p);
-		if (strcmp(selected,*p)==0) active=i;
+	for(;*p!=NULL;++p){
+		if ( cap==CAP_IGNORE 
+			|| (cap==CAP_CAPTURE && linphone_core_sound_device_can_capture(linphone_gtk_get_core(),*p))
+			|| (cap==CAP_PLAYBACK && linphone_core_sound_device_can_playback(linphone_gtk_get_core(),*p)) ){
+			gtk_combo_box_append_text(GTK_COMBO_BOX(combo),*p);
+			if (strcmp(selected,*p)==0) active=i;
+			i++;
+		}
+	}
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo),active);
+}
+
+void linphone_gtk_fill_video_sizes(GtkWidget *combo){
+	const MSVideoSizeDef *def=linphone_core_get_supported_video_sizes(linphone_gtk_get_core());;
+	int i,active=0;
+	char vsize_def[256];
+	MSVideoSize cur=linphone_core_get_preferred_video_size(linphone_gtk_get_core());
+	/* glade creates a combo box without list model and text renderer,
+	unless we fill it with a dummy text.
+	This dummy text needs to be removed first*/
+	gtk_combo_box_remove_text(GTK_COMBO_BOX(combo),0);
+	for(i=0;def->name!=NULL;++def,++i){
+		snprintf(vsize_def,sizeof(vsize_def),"%s (%ix%i)",def->name,def->vsize.width,def->vsize.height);
+		gtk_combo_box_append_text(GTK_COMBO_BOX(combo),vsize_def);
+		if (cur.width==def->vsize.width && cur.height==def->vsize.height) active=i;
 	}
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combo),active);
 }
@@ -153,6 +181,14 @@ void linphone_gtk_cam_changed(GtkWidget *w){
 	g_free(sel);
 }
 
+void linphone_gtk_video_size_changed(GtkWidget *w){
+	int sel=gtk_combo_box_get_active(GTK_COMBO_BOX(w));
+	const MSVideoSizeDef *defs=linphone_core_get_supported_video_sizes(linphone_gtk_get_core());
+	if (sel<0) return;
+	linphone_core_set_preferred_video_size(linphone_gtk_get_core(),
+					defs[sel].vsize);
+}
+
 void linphone_gtk_ring_file_set(GtkWidget *w){
 	gchar *file=gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(w));
 	linphone_core_set_ring(linphone_gtk_get_core(),file);
@@ -558,14 +594,19 @@ void linphone_gtk_remove_proxy(GtkButton *button){
 	if (cfg){
 		linphone_core_remove_proxy_config(linphone_gtk_get_core(),cfg);
 		linphone_gtk_show_sip_accounts(gtk_widget_get_toplevel(GTK_WIDGET(button)));
+		/* also update the main window's list of identities*/
+		linphone_gtk_load_identities();
 	}
 }
 
 void linphone_gtk_edit_proxy(GtkButton *button){
 	GtkWidget *pb=gtk_widget_get_toplevel(GTK_WIDGET(button));
 	LinphoneProxyConfig *cfg=linphone_gtk_get_selected_proxy_config(pb);
-	if (cfg)
+	if (cfg){
 		linphone_gtk_show_proxy_config(pb,cfg);
+		/* also update the main window's list of identities*/
+		linphone_gtk_load_identities();
+	}
 }
 
 void linphone_gtk_show_parameters(void){
@@ -616,13 +657,14 @@ void linphone_gtk_show_parameters(void){
 					linphone_core_get_use_info_for_dtmf(lc));
 	/* MUTIMEDIA CONFIG */
 	linphone_gtk_fill_combo_box(linphone_gtk_get_widget(pb,"playback_device"), sound_devices,
-					linphone_core_get_playback_device(lc));
+					linphone_core_get_playback_device(lc),CAP_PLAYBACK);
 	linphone_gtk_fill_combo_box(linphone_gtk_get_widget(pb,"ring_device"), sound_devices,
-					linphone_core_get_ringer_device(lc));
+					linphone_core_get_ringer_device(lc),CAP_PLAYBACK);
 	linphone_gtk_fill_combo_box(linphone_gtk_get_widget(pb,"capture_device"), sound_devices,
-					linphone_core_get_capture_device(lc));
+					linphone_core_get_capture_device(lc), CAP_CAPTURE);
 	linphone_gtk_fill_combo_box(linphone_gtk_get_widget(pb,"webcams"),linphone_core_get_video_devices(lc),
-					linphone_core_get_video_device(lc));
+					linphone_core_get_video_device(lc),CAP_IGNORE);
+	linphone_gtk_fill_video_sizes(linphone_gtk_get_widget(pb,"video_size"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(pb,"echo_cancelation")),
 					linphone_core_echo_cancelation_enabled(lc));
 
