@@ -81,7 +81,8 @@ typedef enum MSFilterId{
 	MS_H263_OLD_ENC_ID,
 	MS_MIRE_ID,
 	MS_VFW_ID,
-	MS_ICE_ID
+	MS_ICE_ID,
+	MS_VOID_SINK_ID
 } MSFilterId;
 
 
