@@ -31,10 +31,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #define MS_RTP_SEND_SEND_DTMF		MS_FILTER_METHOD(MS_RTP_SEND_ID,1,const char)
 
-#define MS_RTP_RECV_SET_CANDIDATEPAIRS MS_FILTER_METHOD(MS_RTP_RECV_ID,1,struct CandidatePair*)
-
-#define MS_RTP_SEND_SET_CANDIDATEPAIRS MS_FILTER_METHOD(MS_RTP_SEND_ID,2,struct CandidatePair*)
-
 #define MS_RTP_SEND_MUTE_MIC		MS_FILTER_METHOD_NO_ARG(MS_RTP_SEND_ID,3)
 
 #define MS_RTP_SEND_UNMUTE_MIC		MS_FILTER_METHOD_NO_ARG(MS_RTP_SEND_ID,4)
