@@ -288,6 +288,8 @@ MSSndCardDesc aq_card_desc={
 	.set_level=aq_set_level,
 	.get_level=aq_get_level,
 	.set_capture=aq_set_source,
+	.set_control=NULL,
+	.get_control=NULL,
 	.create_reader=ms_aq_read_new,
 	.create_writer=ms_aq_write_new,
 	.uninit=aq_uninit,
