@@ -439,6 +439,8 @@ MSSndCardDesc ca_card_desc={
 	.set_level=ca_set_level,
 	.get_level=ca_get_level,
 	.set_capture=ca_set_source,
+	.set_control=NULL,
+	.get_control=NULL,
 	.create_reader=ms_ca_read_new,
 	.create_writer=ms_ca_write_new,
 	.uninit=ca_uninit,
