@@ -21,6 +21,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "mediastreamer-config.h"
 #endif
 
+extern void __register_ffmpeg_encoders_if_possible(void);
+
 #include "mediastreamer2/mscommon.h"
 #include "mediastreamer2/msfilter.h"
 
@@ -492,7 +494,7 @@ static MSWebCamDesc * ms_web_cam_descs[]={
 #if defined(WIN32) && defined(HAVE_DIRECTSHOW)
 	&ms_directx_cam_desc,
 #endif
-#if defined(WIN32) && !defined(HAVE_DIRECTSHOW)
+#if defined(WIN32) && defined(HAVE_VFW)
 	&ms_vfw_cam_desc,
 #endif
 	&mire_desc,
@@ -534,6 +536,7 @@ void ms_init(){
 			ms_web_cam_manager_register_desc(wm,ms_web_cam_descs[i]);
 		}
 	}
+	__register_ffmpeg_encoders_if_possible();
 #endif
 	ms_message("Loading plugins");
 	ms_load_plugins(PACKAGE_PLUGINS_DIR);
@@ -548,30 +551,6 @@ void ms_exit(){
 #endif
 }
 
-void ms_reload_snd_card(MSSndCardDesc *snd_desc){
-	MSSndCardManager *cm;
-	int i;
-
-	ms_snd_card_manager_destroy();
-
-	ms_message("Registering all soundcard handlers");
-	if (snd_desc!=NULL)
-	{
-		cm=ms_snd_card_manager_get();
-		if (cm!=NULL)
-			ms_snd_card_manager_register_desc(cm,snd_desc);
-		return;
-	}
-
-	/*register SndCardDesc */
-	cm=ms_snd_card_manager_get();
-	for (i=0;ms_snd_card_descs[i]!=NULL;i++){
-		ms_snd_card_manager_register_desc(cm,ms_snd_card_descs[i]);
-	}
-
-	return;
-}
-
 void ms_sleep(int seconds){
 #ifdef WIN32
 	Sleep(seconds*1000);
