@@ -17,6 +17,11 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
+
+#ifdef HAVE_CONFIG_H
+#include "mediastreamer-config.h"
+#endif
+
 #include "mediastreamer2/msfilter.h"
 #include <math.h>
 
@@ -32,17 +37,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <speex/speex_preprocess.h>
 #endif
 
-#ifndef CONF_GRAN_MAX
-#define CONF_GRAN_MAX 12 /* limit for 'too much data' */
-#endif
-
 #define CONF_NSAMPLES 160*4*4 /* (CONF_GRAN/2) */
 #ifndef CONF_MAX_PINS
-#define CONF_MAX_PINS 32
+#define CONF_MAX_PINS 128
 #endif
 
 static const float max_e=(float)32767*32767;
-static const float coef=(float)0.1;
+static const float coef=(float)0.01;
 
 typedef struct Channel{
 	MSBufferizer buff;
@@ -51,6 +52,7 @@ typedef struct Channel{
 	bool_t is_used;
 
 	int is_speaking;
+	int count_speaking;
 
 	int count;
 	int missed;
@@ -64,6 +66,7 @@ typedef struct Channel{
 #endif
 
 	float energy;
+	double average_psd;
 
 } Channel;
 
@@ -89,8 +92,10 @@ typedef struct ConfState{
 
 
 static void channel_init(ConfState *s, Channel *chan, int pos){
+#ifndef DISABLE_SPEEX
 	float f;
 	int val;
+#endif
 	memset(chan, 0, sizeof(Channel));
 	ms_bufferizer_init(&chan->buff);
 #ifndef DISABLE_SPEEX
@@ -128,20 +133,24 @@ static void channel_init(ConfState *s, Channel *chan, int pos){
 
 	/* enable AGC only on local soundcard */
 	val=0;
-	f=8000;
+	f=12000;
 	if (s->agc_level>0 && pos==0)
 		val=1;
 	else if (pos==0 && s->enable_halfduplex>0)
 		val=1;
 	else if ( pos%2==1 && s->enable_halfduplex>0)
-		val=1;
+		val=1; //1; should not do that
 	if (s->agc_level>0)
 		f=(float)s->agc_level;
 
 
 	speex_preprocess_ctl(chan->speex_pp, SPEEX_PREPROCESS_SET_AGC, &val);
 	speex_preprocess_ctl(chan->speex_pp, SPEEX_PREPROCESS_SET_AGC_LEVEL, &f);
+
 	val=s->max_gain;
+	if ( pos%2==1 && s->enable_halfduplex>0)
+		val=1;
+
 	speex_preprocess_ctl(chan->speex_pp, SPEEX_PREPROCESS_SET_AGC_MAX_GAIN, &val);
 
 	val=0;
@@ -161,6 +170,7 @@ static void channel_uninit(Channel *chan){
 	ms_bufferizer_uninit(&chan->buff);
 	chan->is_speaking=0;
 	chan->energy=0;
+	chan->average_psd=0;
 #ifndef DISABLE_SPEEX
 	if (chan->speex_pp!=NULL)
 	    speex_preprocess_state_destroy(chan->speex_pp);
@@ -252,35 +262,44 @@ static bool_t should_process(MSFilter *f, ConfState *s){
 }
 
 #ifndef DISABLE_SPEEX
-static double powerspectrum_stat_beyond8K(struct Channel *chan)
-{
+static double powerspectrum_stat_beyond8K(struct Channel *chan){
 	spx_int32_t ps_size = 0;
 	spx_int32_t *ps = NULL;
 	double mystat = 0;
 	float fftmul = 1.0 / (32768.0);
-
+	int i;
+	
 	speex_preprocess_ctl(chan->speex_pp, SPEEX_PREPROCESS_GET_PSD_SIZE, &ps_size);
 	ps = (spx_int32_t*)ortp_malloc(sizeof(spx_int32_t)*ps_size);
 	speex_preprocess_ctl(chan->speex_pp, SPEEX_PREPROCESS_GET_PSD, ps);
 
-
 	mystat = 0;
-	for (int i=ps_size/2;i < ps_size; i++) {
+	for (i=ps_size/2;i < ps_size; i++) {
 		double yp;
+#if defined(__cplusplus)
 		yp = sqrtf(sqrtf(static_cast<float>(ps[i]))) - 1.0f;
+#else
+		yp = sqrtf(sqrtf((float)(ps[i]))) - 1.0f;
+#endif
 		yp = yp * fftmul;
 		yp = MIN(yp * 3000.0, 1.0);
+		yp = (1 - yp) * (100 - 1.0f);
 		mystat = yp + mystat;
 	}
 
+	mystat = (mystat*2)/ps_size;
+
 	ortp_free(ps);
 
-	/* value between 0 and 100? */
-	mystat = mystat*100*2/ps_size;
-	if (mystat<0)
-		mystat=0;
-	if (mystat>100)
-		mystat=100;
+	/* values:
+	Maximum: 108,064 low volume on high frequency.
+	Decrease when volume increase. */
+
+	/* return value between 0 and 108,064? */
+	mystat = 108.064-mystat;
+
+	chan->average_psd=(mystat*mystat*coef) + (1.0-coef)*chan->average_psd;
+	//ms_message("average power spectrum on half highest values ONLY: stat=%.3lf", chan->average_psd);
 
 	return mystat;
 }
@@ -331,7 +350,6 @@ static void conf_sum(MSFilter *f, ConfState *s){
 #if 0
 			int loudness;
 #endif
-			int vad=0;
 			while (ms_bufferizer_get_avail(&chan->buff)> (ms_bufferizer_get_avail(&s->channels[0].buff)) )
 			{
 				ms_bufferizer_read(&chan->buff,(uint8_t*)chan->input,s->conf_gran);
@@ -342,6 +360,7 @@ static void conf_sum(MSFilter *f, ConfState *s){
 #ifndef DISABLE_SPEEX
 				if (chan->speex_pp!=NULL && s->enable_vad==TRUE)
 				{
+					int vad=0;
 					vad = speex_preprocess(chan->speex_pp, (short*)chan->input, NULL);
 					if (vad==1)
 						break; /* voice detected: process as usual */
@@ -381,10 +400,18 @@ static void conf_sum(MSFilter *f, ConfState *s){
 				en=(s*s*coef) + ((float)1.0-coef)*en;
 			}
 			chan->energy=en;
-			vol.energy = 10*log10f(chan->energy/max_e);
+			vol.energy = chan->energy; //10*log10f(chan->energy/max_e);
 			vol.channel = i;
 			ms_filter_notify(f, MS_CONF_CHANNEL_VOLUME, (void*)&vol);
 
+			if (i>0) /* not for MIC */
+			{
+				if (chan->energy>65)
+					chan->count_speaking++;
+				else
+					chan->count_speaking=0;
+			}
+
 #ifndef DISABLE_SPEEX
 			if (chan->speex_pp!=NULL && s->enable_vad==TRUE && i==0)
 			{
@@ -394,19 +421,28 @@ static void conf_sum(MSFilter *f, ConfState *s){
 
 				if (s->enable_halfduplex>0)
 				{
-					double mystat = powerspectrum_stat_beyond8K(chan);
-					//ms_message("is_speaking (chan=%i) -> on/stat=%.3lf", i, mystat);
-					if (mystat>10)
+					powerspectrum_stat_beyond8K(chan);
+					if (chan->average_psd>s->vad_prob_start)
 					{
-						ms_message("is_speaking (chan=%i) -> on/stat=%.3lf", i, mystat);
-						s->channels[0].is_speaking=20; /* keep RTP muted for the next few ms */
+						if (s->channels[0].is_speaking<0)
+							ms_message("MIC is turned on");
+						//ms_message("is_speaking (chan=%i) -> on/stat=%.3lf", i, chan->average_psd);
+						s->channels[0].is_speaking=20; /* keep RTP unmuted for the next few ms */
 					}
-					else
+					else if (chan->average_psd<s->vad_prob_continue)
 					{
+						if (s->channels[0].is_speaking==0)
+						{
+							ms_message("MIC is turned off");
+							s->channels[0].count_speaking=0;
+						}
 						s->channels[0].is_speaking--;
 					}
+					if (s->channels[0].is_speaking>0)
+					{
+						s->channels[0].count_speaking++;
+					}
 				}
-
 			}
 			else if (chan->speex_pp!=NULL && s->enable_vad==TRUE)
 			{
@@ -481,12 +517,21 @@ static void conf_dispatch(MSFilter *f, ConfState *s){
 	int i;
 	Channel *chan;
 	mblk_t *m;
-	//memset(s->sum,0,s->conf_nsamples*sizeof(int));
+
 	for (i=0;i<CONF_MAX_PINS;++i){
 		if (f->outputs[i]!=NULL){
 			chan=&s->channels[i];
-			if (s->channels[0].is_speaking<0 && i%2==1) // MIC is NOT speaking -> send silence on RTP
-				m=conf_output(s,chan, 5);
+			if (s->channels[0].is_speaking>0 // if MIC is speaking 
+				&& s->channels[0].count_speaking<75 // if MIC was silence a few time ago
+				&& chan->count_speaking>0 // if RTP has started to talk
+				&& chan->count_speaking<75 // if RTP was silence a few ms ago
+				&& i%2==1) // false detection of MIC speaking
+			{
+				ms_message("false detection of MIC speaking: turned off");
+				m=conf_output(s,chan, 32000);
+			}
+			else if (s->channels[0].is_speaking<0 && i%2==1) // MIC is NOT speaking -> send silence on RTP
+				m=conf_output(s,chan, 32000);
 			else
 				m=conf_output(s,chan, 1);
 			ms_queue_put(f->outputs[i],m);
