@@ -137,6 +137,7 @@ static bool_t sdl_display_init(MSDisplay *obj, MSPicture *fbuf){
 		sdl_initialized=TRUE;
 		ms_mutex_init(&sdl_mutex,NULL);
 	}
+	ms_mutex_lock(&sdl_mutex);
 	if (obj->data!=NULL){
 		SDL_FreeYUVOverlay((SDL_Overlay*)obj->data);
 	}
@@ -146,16 +147,20 @@ static bool_t sdl_display_init(MSDisplay *obj, MSPicture *fbuf){
 		fbuf->planes[0]=lay->pixels[0];
 		fbuf->planes[1]=lay->pixels[2];
 		fbuf->planes[2]=lay->pixels[1];
+		fbuf->planes[3]=NULL;
 		fbuf->strides[0]=lay->pitches[0];
 		fbuf->strides[1]=lay->pitches[2];
 		fbuf->strides[2]=lay->pitches[1];
+		fbuf->strides[3]=0;
 		fbuf->w=lay->w;
 		fbuf->h=lay->h;
 		obj->data=lay;
 		sdl_show_window(TRUE);
 		obj->window_id=sdl_get_native_window_id();
+		ms_mutex_unlock(&sdl_mutex);
 		return TRUE;
 	}
+	ms_mutex_unlock(&sdl_mutex);
 	return FALSE;
 }
 
@@ -207,6 +212,8 @@ static bool_t sdl_poll_event(MSDisplay *obj, MSDisplayEvent *ev){
 
 static void sdl_display_uninit(MSDisplay *obj){
 	SDL_Overlay *lay=(SDL_Overlay*)obj->data;
+	SDL_Event event;
+	int i;
 	if (lay==NULL)
 		return;
 	if (lay!=NULL)
@@ -215,6 +222,9 @@ static void sdl_display_uninit(MSDisplay *obj){
 		SDL_FreeSurface(sdl_screen);
 		sdl_screen=NULL;
 	}
+	/*purge the event queue before leaving*/
+	for(i=0;SDL_PollEvent(&event) && i<100;++i){
+	}
 	sdl_show_window(FALSE);
 }
 
@@ -327,6 +337,7 @@ static bool_t win_display_init(MSDisplay *obj, MSPicture *fbuf){
 		wd->fb.planes[0]=NULL;
 		wd->fb.planes[1]=NULL;
 		wd->fb.planes[2]=NULL;
+		wd->fb.planes[3]=NULL;
 		if (wd->rgb) ms_free(wd->rgb);
 		wd->rgb=NULL;
 		wd->rgb_len=0;
@@ -376,9 +387,11 @@ static bool_t win_display_init(MSDisplay *obj, MSPicture *fbuf){
 	fbuf->planes[0]=wd->fb.planes[0]=(uint8_t*)ms_malloc0(ysize+2*usize);
 	fbuf->planes[1]=wd->fb.planes[1]=wd->fb.planes[0]+ysize;
 	fbuf->planes[2]=wd->fb.planes[2]=wd->fb.planes[1]+usize;
+	fbuf->planes[3]=NULL;
 	fbuf->strides[0]=wd->fb.strides[0]=wd->fb.w;
 	fbuf->strides[1]=wd->fb.strides[1]=wd->fb.w/2;
 	fbuf->strides[2]=wd->fb.strides[2]=wd->fb.w/2;
+	fbuf->strides[3]=0;
 
 	wd->rgb_len=ysize*3;
 	wd->rgb=(uint8_t*)ms_malloc0(wd->rgb_len);
@@ -395,15 +408,15 @@ typedef struct yuv{
 
 
 
-static void yuv420p_to_rgb(WinDisplay *wd, MSPicture *src, uint8_t *rgb){
+void yuv420p_to_rgb(WinDisplay *wd, MSPicture *src, uint8_t *rgb){
 	int rgb_stride=-src->w*3;
 	uint8_t *p;
 
 	p=rgb+(src->w*3*(src->h-1));
 	if (wd->sws==NULL){
 		wd->sws=sws_getContext(src->w,src->h,PIX_FMT_YUV420P,
-			src->w,src->h,PIX_FMT_BGR24,
-			0, NULL, NULL, NULL);
+			src->w,src->h, PIX_FMT_BGR24,
+			SWS_FAST_BILINEAR, NULL, NULL, NULL);
 	}
 	if (sws_scale(wd->sws,src->planes,src->strides, 0,
            			src->h, &p, &rgb_stride)<0){
@@ -681,8 +694,10 @@ static int video_out_handle_resizing(MSFilter *f, void *data){
 				sz.width=ev.w;
 				sz.height=ev.h;
 				ms_filter_lock(f);
-				set_vsize(s,&sz);
-				s->ready=FALSE;
+				if (s->ready){
+					set_vsize(s,&sz);
+					s->ready=FALSE;
+				}
 				ms_filter_unlock(f);
 			}
 		}
@@ -790,6 +805,7 @@ static void video_out_process(MSFilter *f){
 		corner.planes[0]+=obj->local_rect.x+(obj->local_rect.y*corner.strides[0]);
 		corner.planes[1]+=(obj->local_rect.x/2)+((obj->local_rect.y/2)*corner.strides[1]);
 		corner.planes[2]+=(obj->local_rect.x/2)+((obj->local_rect.y/2)*corner.strides[2]);
+		corner.planes[3]=0;
 		ms_display_lock(obj->display);
 		yuv_buf_copy(obj->local_pic.planes,obj->local_pic.strides,
 				corner.planes,corner.strides,roi);
@@ -834,6 +850,7 @@ static int video_out_set_corner(MSFilter *f,void *arg){
 		memset(s->fbuf.planes[0], 0, ysize);
 		memset(s->fbuf.planes[1], 0, usize);
 		memset(s->fbuf.planes[2], 0, usize);
+		s->fbuf.planes[3]=NULL;
 		}
 		ms_display_unlock(s->display);
 	}
