@@ -126,6 +126,8 @@ MSSndCardDesc winsndds_card_desc={
 	winsnddscard_set_level,
 	winsnddscard_get_level,
 	winsnddscard_set_source,
+	NULL,
+	NULL,
 	ms_winsndds_read_new,
 	ms_winsndds_write_new,
 	winsnddscard_uninit,
@@ -794,7 +796,7 @@ static MSFilterMethod winsndds_methods[]={
 
 MSFilterDesc winsndds_read_desc={
 	MS_WINSNDDS_READ_ID,
-	"MSWinSndRead",
+	"MSWinSndDsRead",
 	"Sound capture filter for Windows Sound drivers",
 	MS_FILTER_OTHER,
 	NULL,
@@ -811,7 +813,7 @@ MSFilterDesc winsndds_read_desc={
 
 MSFilterDesc winsndds_write_desc={
 	MS_WINSNDDS_WRITE_ID,
-	"MSWinSndWrite",
+	"MSWinSndDsWrite",
 	"Sound playback filter for Windows Sound drivers",
 	MS_FILTER_OTHER,
 	NULL,
