@@ -28,6 +28,9 @@ int main(int argc, char *argv[]){
 	const char *file;
 	MSSndCard *sc;
 	const char * card_id=NULL;
+
+	ortp_init();
+	ortp_set_log_level_mask(ORTP_MESSAGE|ORTP_WARNING|ORTP_ERROR|ORTP_FATAL);
 	ms_init();
 	if (argc>1){
 		file=argv[1];
@@ -35,7 +38,13 @@ int main(int argc, char *argv[]){
 	if (argc>2){
 		card_id=argv[2];
 	}
+
 	sc=ms_snd_card_manager_get_card(ms_snd_card_manager_get(),card_id);
+#ifdef __linux
+	if (sc==NULL)
+	  sc = ms_alsa_card_new_custom(card_id, card_id);
+#endif
+
 	r=ring_start(file,2000,sc);
 	sleep(10);
 	ring_stop(r);
