@@ -87,14 +87,13 @@ void rtp_session_rtp_parse(RtpSession *session, mblk_t *mp, uint32_t local_str_t
 				rtp_session_dispatch_event(session,ev);
 				return;
 			}
-		}else{
-			/* discard*/
-			ortp_debug("Receiving rtp packet with version number !=2...discarded");
-			stats->bad++;
-			ortp_global_stats.bad++;
-			freemsg(mp);
-			return;
 		}
+		/* discard in two case: the packet is not stun OR nobody is interested by STUN (no eventqs) */
+		ortp_debug("Receiving rtp packet with version number !=2...discarded");
+		stats->bad++;
+		ortp_global_stats.bad++;
+		freemsg(mp);
+		return;
 	}
 
 	/* only count non-stun packets. */
@@ -137,6 +136,16 @@ void rtp_session_rtp_parse(RtpSession *session, mblk_t *mp, uint32_t local_str_t
 				session->inc_ssrc_candidate=rtp->ssrc;
 			}
 			if (session->inc_same_ssrc_count>SSRC_CHANGED_THRESHOLD){
+
+				/* store the sender rtp address to do symmetric RTP */
+				if (!session->use_connect){
+					if (session->rtp.socket>0 && session->symmetric_rtp){
+						/* store the sender rtp address to do symmetric RTP */
+						memcpy(&session->rtp.rem_addr,addr,addrlen);
+						session->rtp.rem_addrlen=addrlen;
+					}
+				}
+
 				session->rcv.ssrc=rtp->ssrc;
 				rtp_signal_table_emit(&session->on_ssrc_changed);
 			}else{
@@ -148,9 +157,23 @@ void rtp_session_rtp_parse(RtpSession *session, mblk_t *mp, uint32_t local_str_t
 				return;
 			}
 		}
+    else{
+			/* The SSRC change must not happen if we still receive
+			ssrc from the initial source. */
+			session->inc_same_ssrc_count=0;
+		}
+
 	}else{
 		session->ssrc_set=TRUE;
 		session->rcv.ssrc=rtp->ssrc;
+
+		if (!session->use_connect){
+			if (session->rtp.socket>0 && session->symmetric_rtp){
+				/* store the sender rtp address to do symmetric RTP */
+				memcpy(&session->rtp.rem_addr,addr,addrlen);
+				session->rtp.rem_addrlen=addrlen;
+			}
+		}
 	}
 	
 	/* update some statistics */
