@@ -309,10 +309,10 @@ int rtp_session_read_telephone_event(RtpSession *session,
 	int i;
 	telephone_event_t *tev;
 	rtp_header_t *hdr=(rtp_header_t*)packet->b_rptr;
-	return_val_if_fail(packet->b_cont!=NULL,-1);
+	unsigned char *payload;
 	if (hdr->paytype!=session->rcv.telephone_events_pt) return 0;  /* this is not tel ev.*/
-	datasize=msgdsize(packet);
-	tev=*tab=(telephone_event_t*)packet->b_cont->b_rptr;
+	datasize=rtp_get_payload(packet,&payload);
+	tev=*tab=(telephone_event_t*)payload;
 	/* convert from network to host order what should be */
 	num=datasize/sizeof(telephone_event_t);
 	for (i=0;i<num;i++)
@@ -348,17 +348,19 @@ static void notify_events_ended(RtpSession *session, telephone_event_t *events,
 void rtp_session_check_telephone_events(RtpSession *session, mblk_t *m0)
 {
 	telephone_event_t *events,*evbuf;
-	int num;
+	int num,num2;
 	int i;
-	mblk_t *mp;
 	rtp_header_t *hdr;
 	mblk_t *cur_tev;
+	unsigned char *payload;
+	int datasize;
 	
 	hdr=(rtp_header_t*)m0->b_rptr;
-	mp=m0->b_cont;
 	
-	num=((int)(mp->b_wptr-mp->b_rptr))/sizeof(telephone_event_t);
-	events=(telephone_event_t*)mp->b_rptr;
+	datasize=rtp_get_payload(m0,&payload);
+
+	num=datasize/sizeof(telephone_event_t);
+	events=(telephone_event_t*)payload;
 	
 	
 	if (hdr->markbit==1)
@@ -380,8 +382,10 @@ void rtp_session_check_telephone_events(RtpSession *session, mblk_t *m0)
 		if (((rtp_header_t*)cur_tev->b_rptr)->timestamp==
 			((rtp_header_t*)m0->b_rptr)->timestamp)
 		{
-			evbuf=(telephone_event_t*)cur_tev->b_cont;
-			for (i=0;i<num;i++)
+			datasize=rtp_get_payload(cur_tev,&payload);
+			num2=datasize/sizeof(telephone_event_t);
+			evbuf=(telephone_event_t*)payload;
+			for (i=0;i<MIN(num,num2);i++)
 			{
 				if (events[i].E==1)
 				{
